@@ -20,7 +20,7 @@ class StaticGeneratorMiddleware(object):
     def process_response(self, request, response):
         if response.status_code == 200:
             for url in self.urls:
-                if url.match(request.path):
-                    self.gen.publish_from_path(request.path, response.content)
+                if url.match(request.path_info):
+                    self.gen.publish_from_path(request.path_info, response.content)
                     break
-        return response
\ No newline at end of file
+        return response
